@@ -2,8 +2,9 @@
 import json
 import logging
 import threading
+import traceback
 from threading import Thread
-from celery import Celery
+from celery import Celery, exceptions
 from celery.result import AsyncResult
 from redis import Redis
 
@@ -39,7 +40,7 @@ class CeleryRedisResultMonitor(object):
         while True:
             filter_key = get_result_key_filter(app_code=self.app_code)
             keys = self.rds_client.keys(filter_key)
-            LOGGER.debug(f'扫描[{threading.currentThread()}]: keys={len(keys)}')
+            # LOGGER.debug(f'扫描[{threading.currentThread()}]: keys={len(keys)}')
             if keys:
                 for key in keys:
                     task_id = get_task_id_from_key(key)
@@ -47,17 +48,24 @@ class CeleryRedisResultMonitor(object):
                         async_result = AsyncResult(id=task_id, app=self.celery_client)
                         if async_result.successful():
                             # 完成
-                            result = async_result.get()
-                            callback = json.loads(self.rds_client.get(key))
-                            callback_func = callback.get('callback_func', None)
-                            callback_data = callback.get('callback_data', None)
-                            if callback_func:
-                                func = ref_to_obj(callback_func)
-                                thread_pool.submit(func, result, callback_data)
-                                LOGGER.debug(f'结果: task={task_id}, func={callback_func}')
-                            else:
-                                LOGGER.debug(f'未处理: task={task_id}')
-                            self._remove_task(key, async_result)
+                            try:
+                                result = async_result.get()
+                                callback = json.loads(self.rds_client.get(key))
+                                callback_func = callback.get('callback_func', None)
+                                callback_data = callback.get('callback_data', None)
+                                if callback_func:
+                                    func = ref_to_obj(callback_func)
+                                    thread_pool.submit(func, result, callback_data)
+                                else:
+                                    LOGGER.warning(f'无回调: task={task_id}')
+                                # 清理
+                                self._remove_task(key, async_result)
+                            except exceptions.TimeoutError as te:
+                                LOGGER.error(f'异常: 结果获取超时 task={task_id}, e={traceback.format_exc()}')
+                            except LookupError as le:
+                                LOGGER.error(f'异常: 回调函数反序列化异常 task={task_id}, e={traceback.format_exc()}')
+                            except Exception as e:
+                                LOGGER.error(f'异常: 结果处理异常 task={task_id}, e={traceback.format_exc()}')
                         elif async_result.failed():
                             # 失败
                             self._remove_task(key, async_result)
